@@ -10,6 +10,7 @@ from django.contrib.auth.models import User
 from django.contrib.auth import authenticate, login
 from django.conf import settings
 from django.core import serializers
+from django.core.mail import send_mail
 from django.core.servers.basehttp import FileWrapper
 from django.db import IntegrityError
 from django.http import HttpRequest, HttpResponse ,Http404
@@ -172,6 +173,10 @@ class RegisterResource(ModelResource):
             
             user_profile = UserProfile()
             user_profile.user = bundle.obj
+            if 'jobtitle' in bundle.data:
+                user_profile.job_title = bundle.data['jobtitle']
+            if 'organisation' in bundle.data:
+                user_profile.organisation = bundle.data['organisation']
             user_profile.save()
             
             u = authenticate(username=username, password=password)
@@ -211,6 +216,53 @@ class RegisterResource(ModelResource):
     
     def dehydrate_metadata(self,bundle):
         return settings.OPPIA_METADATA
+
+class ResetPasswordResource(ModelResource):
+    ''' 
+    For resetting user password
+    '''
+    message = fields.CharField()
+    
+    class Meta:
+        queryset = User.objects.all()
+        resource_name = 'reset'
+        allowed_methods = ['post']
+        fields = ['username','message']
+        authorization = Authorization() 
+        always_return_data = True 
+        include_resource_uri = False   
+    
+    def obj_create(self, bundle, **kwargs):
+        required = ['username',]
+        for r in required:
+            try:
+                bundle.data[r]
+            except KeyError:
+                raise BadRequest(_(u'Please enter your %s') % r)
+         
+        bundle.obj.username = bundle.data['username']
+        try:
+            user = User.objects.get(username__exact=bundle.obj.username)
+            newpass = User.objects.make_random_password(length=8)
+            user.set_password(newpass)
+            user.save()
+            if bundle.request.is_secure():
+                prefix = 'https://'
+            else:
+                prefix = 'http://'
+            # TODO - better way to manage email message content
+            send_mail('OppiaMobile: Password reset', 'Here is your new password for OppiaMobile: '+newpass 
+                      + '\n\nWhen you next log in you can update your password to something more memorable.' 
+                      + '\n\n' + prefix + bundle.request.META['SERVER_NAME'] , 
+                      settings.SERVER_EMAIL, [user.email], fail_silently=False) 
+        except User.DoesNotExist:
+            pass
+        
+        return bundle       
+        
+    def dehydrate_message(self,bundle):
+        message = _(u'An email has been sent to your registered email address with your new password')
+        return message
     
 class TrackerResource(ModelResource):
     ''' 
