@@ -39,14 +39,14 @@ def home_view(request):
             day = temp.strftime("%d")
             month = temp.strftime("%m")
             year = temp.strftime("%Y")
-            count = Tracker.objects.filter(course__isnull=False, course__is_draft=False, course__is_archived=False,tracker_date__day=day,tracker_date__month=month,tracker_date__year=year).count()
+            count = Tracker.objects.filter(course__isnull=False, course__is_draft=False, user__is_staff=False, course__is_archived=False,tracker_date__day=day,tracker_date__month=month,tracker_date__year=year).count()
             activity.append([temp.strftime("%d %b %Y"),count])
     leaderboard = Points.get_leaderboard(10)
     return render_to_response('oppia/home.html',{'recent_activity':activity, 'leaderboard':leaderboard}, context_instance=RequestContext(request))
 
 def course_view(request):
     if request.user.is_staff:
-        course_list = Course.objects.all().order_by('title')
+        course_list = Course.objects.filter(is_archived=False).order_by('title')
     else:
         course_list = Course.objects.filter(is_draft=False,is_archived=False).order_by('title')   
     startdate = datetime.datetime.now()
@@ -58,7 +58,7 @@ def course_view(request):
             month = temp.strftime("%m")
             year = temp.strftime("%Y")
             
-            count = Tracker.objects.filter(course = course, tracker_date__day=day,tracker_date__month=month,tracker_date__year=year).count()
+            count = Tracker.objects.filter(course = course, user__is_staff=False, tracker_date__day=day,tracker_date__month=month,tracker_date__year=year).count()
             course.activity.append([temp.strftime("%d %b %Y"),count])  
     return render_to_response('oppia/course/course.html',{'course_list': course_list}, context_instance=RequestContext(request))
 
@@ -261,7 +261,7 @@ def schedule_edit(request,course_id, schedule_id):
             schedule.default = form.cleaned_data.get("default")
             schedule.lastupdated_date = datetime.datetime.now()
             
-            # remvoe any existing default for this schedule
+            # remove any existing default for this schedule
             if schedule.default:
                 Schedule.objects.filter(course=course).update(default=False)
                 
@@ -481,7 +481,7 @@ def course_quiz(request,course_id):
     return render_to_response('oppia/course/quizzes.html',{'course': course, 'nav': nav, 'quizzes':quizzes}, context_instance=RequestContext(request))
 
 def course_quiz_attempts(request,course_id,quiz_id):
-    #get the quiz digests for this course
+    # get the quiz digests for this course
     course = check_owner(request,course_id)
     quiz = Quiz.objects.get(pk=quiz_id)
     attempts = QuizAttempt.objects.filter(quiz=quiz).order_by('-attempt_date')
